// RockUp
// Commands-Prepare -- Prepare the server-side to accept deployments

var Config = require('../lib/Config');
var reduceAsync = require('../lib/Async').reduce;

module.exports = PrepareCommand;

function PrepareCommand (program) {
  program
    .command("prep <environment>")
    .description("Prepare a server host to accept deployments")
    .option("--host <name>", "Specify an individual host to prep")
    .action( function(env, cliOptions) {
      var config = Config._loadLocalConfigFile(env);

      var hosts = cliOptions.host ? [config.hosts.get(cliOptions.host)] : config.hosts.list;
      var numHosts = hosts.length;

      var operations = _.map(hosts, function(host) {
        if (!host) { console.error("Cannot find host".red.bold, "\n"); process.exit(1); }
        return function (memo, cb) {
          host.prepare( function(results) {
            if (results[host.name].error)
              memo[host.name] = false;
            else
              memo[host.name] = _.every(results[host.name].history, function(obj) {
                return obj.status === 'SUCCESS';
              });
            cb();
          });
        };
      });

      function _allHostsComplete (hostMap) {
        console.log("\nPreparation complete for "+numHosts+" host(s):");
        _.each(hostMap, function(success, hostName) {
          console.log(hostName.bold, "\t", success ? 'SUCCESS'.green.bold : 'FAIL'.red.bold);  
        });
        console.log("");
        process.exit(0);
      }

      operations.unshift({});
      operations.push(_allHostsComplete);
      reduceAsync.apply(this, operations);
      
    });
  return program;
}
